@@ -93,6 +93,21 @@ def pull_image(name):
         LOG.debug(stderr)
 
 
+def get_config_base(prefix, volume):
+    # crawl the volume's path upwards until we find the
+    # volume's base, where the hashed config file resides
+    path = volume
+    base = prefix.rstrip(os.path.sep)
+    base_generated = os.path.join(base, 'puppet-generated')
+    while path.startswith(prefix):
+        dirname = os.path.dirname(path)
+        if dirname == base or dirname == base_generated:
+            return path
+        else:
+            path = dirname
+    raise ValueError("Could not find config's base for '%s'" % volume)
+
+
 def match_config_volumes(prefix, config):
     # Match the mounted config volumes - we can't just use the
     # key as e.g "novacomute" consumes config-data/nova
@@ -106,8 +121,8 @@ def match_config_volumes(prefix, config):
             )
         )
         raise
-    return sorted([os.path.dirname(v.split(":")[0]) for v in volumes if
-                   v.startswith(prefix)])
+    return sorted([get_config_base(prefix, v.split(":")[0])
+                   for v in volumes if v.startswith(prefix)])
 
 
 def get_config_hash(config_volume):
@@ -131,38 +146,6 @@ def get_config_hash(config_volume):
     return hash_data
 
 
-def rm_container(name):
-    if os.environ.get('SHOW_DIFF', None):
-        LOG.info('Diffing container: %s' % name)
-        stdout, stderr, retval = local_subprocess_call(
-            cmd=[CLI_CMD, 'diff', name]
-        )
-        if stdout:
-            LOG.debug(stdout)
-        if stderr:
-            LOG.debug(stderr)
-
-    def rm_process_call(rm_cli_cmd):
-        stdout, stderr, retval = local_subprocess_call(
-            cmd=rm_cli_cmd)
-        if stdout:
-            LOG.debug(stdout)
-        if stderr and 'Error response from daemon' in stderr:
-            LOG.debug(stderr)
-
-    LOG.info('Removing container: %s' % name)
-    rm_cli_cmd = [CLI_CMD, 'rm']
-    rm_cli_cmd.append(name)
-    rm_process_call(rm_cli_cmd)
-    # --storage is used as a mitigation of
-    # https://github.com/containers/libpod/issues/3906
-    # Also look https://bugzilla.redhat.com/show_bug.cgi?id=1747885
-    if CONTAINER_CLI == 'podman':
-        rm_storage_cli_cmd = [CLI_CMD, 'rm', '--storage']
-        rm_storage_cli_cmd.append(name)
-        rm_process_call(rm_storage_cli_cmd)
-
-
 def mp_puppet_config(*args):
     (
         config_volume,
@@ -193,14 +176,20 @@ def mp_puppet_config(*args):
         uname = RUNNER.unique_container_name(
             'container-puppet-%s' % config_volume
         )
-        rm_container(uname)
+        LOG.info('Removing container: %s' % uname)
+        RUNNER.remove_container(uname)
         pull_image(config_image)
 
         common_dcmd = [
             CLI_CMD,
             'run',
             '--user',
-            'root',
+            # Using '0' and not 'root' because it seems podman is susceptible to a race condition
+            # https://bugzilla.redhat.com/show_bug.cgi?id=1776766 and
+            # https://bugs.launchpad.net/tripleo/+bug/1803544 which are still lurking
+            # by using a UID we skip the code that parses /etc/passwd entirely and basically
+            # paper over this issue
+            '0',
             '--name',
             uname,
             '--env',
@@ -321,7 +310,8 @@ def mp_puppet_config(*args):
                 if stderr:
                     LOG.warning(stderr)
                 # only delete successful runs, for debugging
-                rm_container(uname)
+                LOG.info('Removing container: %s' % uname)
+                RUNNER.remove_container(uname)
                 break
             time.sleep(3)
             LOG.error(
@@ -331,6 +321,9 @@ def mp_puppet_config(*args):
                     count
                 )
             )
+
+            LOG.info('Removing container: %s' % uname)
+            RUNNER.remove_container(uname)
             LOG.warning('Retrying running container: %s' % config_volume)
         else:
             if stdout:
@@ -572,11 +565,13 @@ if __name__ == '__main__':
     # Update the startup configs with the config hash we generated above
     STARTUP_CONFIGS = os.environ.get(
         'STARTUP_CONFIG_PATTERN',
-        '/var/lib/tripleo-config/docker-container-startup-config-step_*.json'
+        '/var/lib/tripleo-config/'
+        'container-startup-config/'
+        'step_' + os.environ.get('STEP', '6') + '/*.json'
     )
     LOG.debug('STARTUP_CONFIG_PATTERN: %s' % STARTUP_CONFIGS)
     # Run infile processing
     infile_processing(infiles=glob.glob(STARTUP_CONFIGS))
 
     if not SUCCESS:
-        raise SystemExit()
+        raise SystemExit(1)
