@@ -271,7 +271,7 @@ def to_camel_case(string):
 def get_base_endpoint_map(filename):
     try:
         with open(filename, 'r') as f:
-            tpl = yaml.load(f.read(), Loader=yaml.FullLoader)
+            tpl = yaml.load(f.read(), Loader=yaml.SafeLoader)
         return tpl['parameters']['EndpointMap']['default']
     except Exception:
         print(traceback.format_exc())
@@ -281,7 +281,7 @@ def get_base_endpoint_map(filename):
 def get_endpoint_map_from_env(filename):
     try:
         with open(filename, 'r') as f:
-            tpl = yaml.load(f.read(), Loader=yaml.FullLoader)
+            tpl = yaml.load(f.read(), Loader=yaml.SafeLoader)
         return {
             'file': filename,
             'map': tpl['parameter_defaults']['EndpointMap']
@@ -297,7 +297,7 @@ def validate_endpoint_map(base_map, env_map):
 
 def validate_role_name(filename):
     with open(filename, 'r') as f:
-        tpl = yaml.load(f.read(), Loader=yaml.FullLoader)
+        tpl = yaml.load(f.read(), Loader=yaml.SafeLoader)
 
     role_data = tpl[0]
     if role_data['name'] != os.path.basename(filename).split('.')[0]:
@@ -313,7 +313,7 @@ def validate_hci_compute_services_default(env_filename, env_tpl):
     roles_filename = os.path.join(os.path.dirname(env_filename),
                                   '../roles/Compute.yaml')
     with open(roles_filename, 'r') as f:
-        roles_tpl = yaml.load(f.read(), Loader=yaml.FullLoader)
+        roles_tpl = yaml.load(f.read(), Loader=yaml.SafeLoader)
 
     for role in roles_tpl:
         if role['name'] == 'Compute':
@@ -329,7 +329,7 @@ def validate_hci_computehci_role(hci_role_filename, hci_role_tpl):
     compute_role_filename = os.path.join(os.path.dirname(hci_role_filename),
                                          './Compute.yaml')
     with open(compute_role_filename, 'r') as f:
-        compute_role_tpl = yaml.load(f.read(), Loader=yaml.FullLoader)
+        compute_role_tpl = yaml.load(f.read(), Loader=yaml.SafeLoader)
 
     compute_role_services = compute_role_tpl[0]['ServicesDefault']
     for role in hci_role_tpl:
@@ -347,7 +347,7 @@ def validate_controller_dashboard(filename, tpl):
     control_role_filename = os.path.join(os.path.dirname(filename),
                                          './Controller.yaml')
     with open(control_role_filename, 'r') as f:
-        control_role_tpl = yaml.load(f.read(), Loader=yaml.FullLoader)
+        control_role_tpl = yaml.load(f.read(), Loader=yaml.SafeLoader)
 
     control_role_services = control_role_tpl[0]['ServicesDefault']
     for role in tpl:
@@ -360,13 +360,30 @@ def validate_controller_dashboard(filename, tpl):
     return 0
 
 
+def validate_controller_storage_nfs(filename, tpl, exclude_service=()):
+    control_role_filename = os.path.join(os.path.dirname(filename),
+                                         './Controller.yaml')
+    with open(control_role_filename, 'r') as f:
+        control_role_tpl = yaml.load(f.read(), Loader=yaml.SafeLoader)
+
+    control_role_services = control_role_tpl[0]['ServicesDefault']
+    for role in tpl:
+        if role['name'] == 'ControllerStorageNfs':
+            services = [x for x in role['ServicesDefault'] if (x not in exclude_service)]
+            if sorted(services) != sorted(control_role_services):
+                print('ERROR: ServicesDefault in %s is different from '
+                      'ServicesDefault in roles/Controller.yaml' % filename)
+                return 1
+    return 0
+
+
 def validate_hci_role(hci_role_filename, hci_role_tpl):
     role_files = ['HciCephAll', 'HciCephFile', 'HciCephMon', 'HciCephObject']
     if hci_role_filename in ['./roles/' + x + '.yaml' for x in role_files]:
         compute_role_filename = \
             os.path.join(os.path.dirname(hci_role_filename), './Compute.yaml')
         with open(compute_role_filename, 'r') as f:
-            compute_role_tpl = yaml.load(f.read(), Loader=yaml.FullLoader)
+            compute_role_tpl = yaml.load(f.read(), Loader=yaml.SafeLoader)
 
         compute_role_services = compute_role_tpl[0]['ServicesDefault']
         for role in hci_role_tpl:
@@ -405,7 +422,7 @@ def validate_ceph_role(ceph_role_filename, ceph_role_tpl):
         ceph_storage_role_filename = \
             os.path.join(os.path.dirname(ceph_role_filename), './CephStorage.yaml')
         with open(ceph_storage_role_filename, 'r') as f:
-            ceph_storage_role_tpl = yaml.load(f.read(), Loader=yaml.FullLoader)
+            ceph_storage_role_tpl = yaml.load(f.read(), Loader=yaml.SafeLoader)
 
         ceph_storage_role_services = ceph_storage_role_tpl[0]['ServicesDefault']
         for role in ceph_role_tpl:
@@ -436,7 +453,7 @@ def validate_controller_no_ceph_role(filename, tpl):
     control_role_filename = os.path.join(os.path.dirname(filename),
                                          './Controller.yaml')
     with open(control_role_filename, 'r') as f:
-        control_role_tpl = yaml.load(f.read(), Loader=yaml.FullLoader)
+        control_role_tpl = yaml.load(f.read(), Loader=yaml.SafeLoader)
 
     control_role_services = control_role_tpl[0]['ServicesDefault']
     for role in tpl:
@@ -460,7 +477,7 @@ def validate_with_compute_role_services(role_filename, role_tpl, exclude_service
     cmpt_filename = os.path.join(os.path.dirname(role_filename),
                                  './Compute.yaml')
     with open(cmpt_filename, 'r') as f:
-        cmpt_tpl = yaml.load(f.read(), Loader=yaml.FullLoader)
+        cmpt_tpl = yaml.load(f.read(), Loader=yaml.SafeLoader)
 
     cmpt_services = cmpt_tpl[0]['ServicesDefault']
     cmpt_services = [x for x in cmpt_services if (x not in exclude_service)]
@@ -596,7 +613,7 @@ def validate_docker_service_mysql_usage(filename, tpl):
                 newfilename = \
                     os.path.normpath(os.path.join(os.path.dirname(incfile), f))
                 with open(newfilename, 'r') as newfile:
-                    newtmp = yaml.load(newfile.read(), Loader=yaml.FullLoader)
+                    newtmp = yaml.load(newfile.read(), Loader=yaml.SafeLoader)
                 read_all(newfile, newtmp)
 
     read_all(filename, tpl)
@@ -1051,7 +1068,7 @@ def validate(filename, param_map):
     retval = 0
     try:
         with open(filename, 'r') as f:
-            tpl = yaml.load(f.read(), Loader=yaml.FullLoader)
+            tpl = yaml.load(f.read(), Loader=yaml.SafeLoader)
 
         is_heat_template = 'heat_template_version' in tpl
 
@@ -1104,9 +1121,18 @@ def validate(filename, param_map):
             retval = validate_role_name(filename)
 
         if filename.startswith('./roles/ComputeHCI.yaml') or \
-                filename.startswith('./roles/ComputeHCIOvsDpdk.yaml'):
+                filename.startswith('./roles/ComputeHCIOvsDpdk.yaml') or \
+                filename.startswith('./roles/ComputeHCISriov.yaml'):
             retval |= validate_hci_computehci_role(filename, tpl)
 
+        if filename.startswith('./roles/ControllerStorageNfs.yaml'):
+            exclude = [
+                'OS::TripleO::Services::CephNfs']
+            retval |= validate_controller_storage_nfs(filename, tpl, exclude)
+
+        if filename.startswith('./roles/ControllerStorageDashboard.yaml'):
+            retval |= validate_controller_dashboard(filename, tpl)
+
         if filename.startswith('./roles/ComputeOvsDpdk.yaml') or \
                 filename.startswith('./roles/ComputeSriov.yaml') or \
                 filename.startswith('./roles/ComputeOvsDpdkRT.yaml') or \
@@ -1235,11 +1261,11 @@ def validate_upgrade_tasks(upgrade_tasks):
 def validate_network_data_file(data_file_path):
     try:
         with open(data_file_path, 'r') as data_file:
-            data_file = yaml.load(data_file.read(), Loader=yaml.FullLoader)
+            data_file = yaml.load(data_file.read(), Loader=yaml.SafeLoader)
 
         base_file_path = os.path.dirname(data_file_path) + "/network_data.yaml"
         with open(base_file_path, 'r') as base_file:
-            base_file = yaml.load(base_file.read(), Loader=yaml.FullLoader)
+            base_file = yaml.load(base_file.read(), Loader=yaml.SafeLoader)
 
         retval = 0
         for n in base_file:
